==> 1.0.123+1.tar.gz: lib/components/UikButton.dart <==
import 'package:flutter/material.dart';
import 'package:ui_sdk/components/UikWidget.dart';
import 'package:ui_sdk/components/WidgetType.dart';
import 'package:ui_sdk/props/UikButtonProps.dart';
import 'package:ui_sdk/utils/UikActionListner.dart';

class UikButton extends UikWidget {
  WidgetType _widgetType;
  UikButtonProps _uikButtonProps;

  UikButton(
    this._widgetType,
    this._uikButtonProps,
  ) : super(_widgetType, _uikButtonProps);

  @override
  _UikButtonState createState() => _UikButtonState(_uikButtonProps);
}

class _UikButtonState extends State<UikButton> {
  UikButtonProps _uikButtonProps;

  _UikButtonState(this._uikButtonProps);

  @override
  Widget build(BuildContext context) {
    return InkWell(
      onTap: () async {
        await executeUikWidgetAction(_uikButtonProps.action);
      },
      child: Container(
        alignment: Alignment.center,
        width: _uikButtonProps.width ?? MediaQuery.sizeOf(context).width,
        height: _uikButtonProps.height ?? 60,
        decoration: BoxDecoration(
            boxShadow: kElevationToShadow[_uikButtonProps.elevation ?? 0],
            color: _uikButtonProps.backgroundColor,
            border: Border.all(
              color: _uikButtonProps.borderColor,
            ),
            borderRadius:
                BorderRadius.circular(_uikButtonProps.borderRadius ?? 0)),
        padding: EdgeInsets.symmetric(
          horizontal: _uikButtonProps.horizontalPadding!,
          vertical: _uikButtonProps.verticalPadding!,
        ),
        margin: EdgeInsets.only(
          left: _uikButtonProps.leftMargin,
          bottom: _uikButtonProps.bottomMargin,
          right: _uikButtonProps.rightMargin,
          top: _uikButtonProps.topMargin,
        ),
        child: Row(
          crossAxisAlignment: CrossAxisAlignment.center,
          mainAxisAlignment: MainAxisAlignment.center,
          mainAxisSize: MainAxisSize.min,
          children: [
            (_uikButtonProps.icon != null)
                ? _uikButtonProps.icon!
                : const SizedBox.shrink(),
            (_uikButtonProps.icon != null)
                ? const SizedBox(
                    width: 4,
                  )
                : const SizedBox.shrink(),
            _uikButtonProps.text ?? const Text('Text has not been set')
          ],
        ),
      ),
    );
  }
}

==> 1.0.128+1.tar.gz: lib/components/UikButton.dart <==
import 'package:flutter/material.dart';
import 'package:flutter_bloc/flutter_bloc.dart';
import 'package:ui_sdk/ApiResponseState.dart';
import 'package:ui_sdk/components/UikWidget.dart';
import 'package:ui_sdk/components/WidgetType.dart';
import 'package:ui_sdk/props/UikButtonProps.dart';
import 'package:ui_sdk/utils/UikActionListner.dart';

class UikButton extends UikWidget {
  WidgetType _widgetType;
  UikButtonProps _uikButtonProps;

  UikButton(
    this._widgetType,
    this._uikButtonProps,
  ) : super(_widgetType, _uikButtonProps);

  @override
  _UikButtonState createState() => _UikButtonState(_uikButtonProps);
}

class _UikButtonState extends State<UikButton> {
  UikButtonProps _uikButtonProps;

  _UikButtonState(this._uikButtonProps);

  @override
  Widget build(BuildContext context) {
    return InkWell(
      onTap: () async {
        await executeUikWidgetAction(_uikButtonProps.action, context);
      },
      child: Container(
        alignment: Alignment.center,
        width: _uikButtonProps.width ?? MediaQuery.sizeOf(context).width,
        height: _uikButtonProps.height ?? 60,
        decoration: BoxDecoration(
            boxShadow: kElevationToShadow[_uikButtonProps.elevation ?? 0],
            color: _uikButtonProps.backgroundColor,
            border: Border.all(
              color: _uikButtonProps.borderColor,
            ),
            borderRadius:
                BorderRadius.circular(_uikButtonProps.borderRadius ?? 0)),
        padding: EdgeInsets.symmetric(
          horizontal: _uikButtonProps.horizontalPadding!,
          vertical: _uikButtonProps.verticalPadding!,
        ),
        margin: EdgeInsets.only(
          left: _uikButtonProps.leftMargin,
          bottom: _uikButtonProps.bottomMargin,
          right: _uikButtonProps.rightMargin,
          top: _uikButtonProps.topMargin,
        ),
        child: Row(
          crossAxisAlignment: CrossAxisAlignment.center,
          mainAxisAlignment: MainAxisAlignment.center,
          mainAxisSize: MainAxisSize.min,
          children: [
            (_uikButtonProps.icon != null)
                ? _uikButtonProps.icon!
                : const SizedBox.shrink(),
            (_uikButtonProps.icon != null)
                ? const SizedBox(
                    width: 4,
                  )
                : const SizedBox.shrink(),
            _uikButtonProps.text ?? const Text('Text has not been set')
          ],
        ),
      ),
    );
  }
}
